==> Products.ThemeCentre-1.1.zip: Products.ThemeCentre-1.1/Products/ThemeCentre/setuphandlers.py <==
from zope.interface import directlyProvides, directlyProvidedBy
from zope.app.event.objectevent import ObjectModifiedEvent, Attributes
from zope.event import notify

from Products.CMFCore.utils import getToolByName
from eea.themecentre.interfaces import IThemeCentreSchema, IThemeCentre, IThemeRelation, IThemeTagging
from eea.themecentre.browser.themecentre import PromoteThemeCentre
from Products.CMFPlone.browser.interfaces import INavigationRoot
from Products.NavigationManager.sections import INavigationSectionPosition

import os
from Globals import package_home
from Products.ThemeCentre import GLOBALS
from Acquisition import aq_inner


def migrateListFeeds2pageWithRelatedFeed(context):
    site = context.getSite()
    logger = context.getLogger('themecentre')
    catalog = getToolByName(site, 'portal_catalog')
    results = catalog.searchResults( object_provides = 'eea.themecentre.interfaces.IThemeCentre' )
    wf = getToolByName(site, 'portal_workflow')
    for tBrain in results:
        theme = tBrain.getObject()
        
        if not hasattr(aq_inner(theme), 'reports'):
            feed_title = 'reports_%s' % theme.getId()
            feed = catalog.searchResults(portal_type='RSSFeedRecipe',
                                         id=feed_title)
            if feed:
                theme.invokeFactory('Document', id='reports')
                reportPage = theme['reports']
                reportPage.setTitle('Reports')
                reportPage.setRelatedItems(feed[0].getObject().UID())
                wf.doActionFor(reportPage, 'publish')
            else:
                logger.info("themecentre (Wise migration): No feed %s " % feed_title )

        docId = 'maps-and-graphs'
        if not hasattr(aq_inner(theme), docId):
           feed = theme['rdf-repository'].Atlas
           theme.invokeFactory('Document', id=docId)
           doc = theme[docId]
           doc.setTitle('Maps and graphs')
           doc.setRelatedItems(feed.UID())
           wf.doActionFor(doc, 'publish')

        docId = 'datasets'
        if not hasattr(aq_inner(theme), docId):
           feed = theme['rdf-repository'].datasets
           theme.invokeFactory('Document', id=docId)
           doc = theme[docId]
           doc.setTitle('Datasets')
           doc.setRelatedItems(feed.UID())
           wf.doActionFor(doc, 'publish')


            
def migrateWise2ThemeCentre(context):
    # only run this step if we are in ThemeCentre profile
    if context.readDataFile('themecentre_migrate_wise.txt') is None:
        return

    site = context.getSite()
    logger = context.getLogger('themecentre')

    siteFolder = getattr(site, 'SITE', None)
    if siteFolder is None:
        return
    
    themes = getattr(site, 'themes', None)
    if themes is None:
        return

    water = getattr(themes, 'old-water', None)
    if water is None:
        logger.info("themecentre (Wise migration): No old water, migration skipped")
        return

    wise = themes.water

    # reload WISE profile
    setup_tool = getToolByName(site, 'portal_setup')
    setup_tool.setImportContext('profile-WISETheme:wisetheme')
    setup_tool.runImportStep('cssregistry')
    setup_tool.runImportStep('skins')    
    setup_tool.setImportContext('profile-ThemeCentre:themecentre')

    # move stuff from water ThemeCentre
    objToMove = water.manage_cutObjects(ids=('indicators',))
    wise.manage_pasteObjects(objToMove)
    logger.info("themecentre (Wise migration): Moved indicators to wise folder")

    # enable Theme Centre on wise folder
    ptc = PromoteThemeCentre(wise, site.REQUEST)
    ptc()
    tc = IThemeCentreSchema(wise)
    tc.tags = 'water'
    logger.info("themecentre (Wise migration): Enabled theme centre on wise folder")

    # migrate related themes
    old = IThemeRelation(water)
    wiserelation = IThemeRelation(wise)
    wiserelation.related = old.related
    
    # disable old water as a theme centre
    tc = IThemeCentreSchema(water)
    tc.tags = None
    directlyProvides(water, directlyProvidedBy(wise)-IThemeCentre)
    logger.info("themecentre (Wise migration): Disabled theme centre on old water folder")
    # rename old-water to old-water-migrated, remove it manually when done
    themes.manage_renameObjects(ids=('old-water',), new_ids=('old-water-migrated',))
    logger.info("themecentre (Wise migration): Renamed old-water to old-water-migrated")    

    

    # rermove navigation root on wise
    directlyProvides(wise, directlyProvidedBy(wise)-INavigationRoot)
    logger.info("themecentre (Wise migration): Removed INavigationRoot on wise folder")

    # setup wise navigation
    wiseNave = { 'topics' : [ 'european-waters', 'water-pollution',
                                'status-and-monitoring', 'water-resources',
                                'water-management', 'links-to-mapviewer-2',
                                'wise-help-centre', 'wise-evaluation-survey'],
                 'data-center-services' : [ 'data-center-services'],
                 'featured' : [ 'featured-articles', 'map-of-the-week'],
                 'about' : [ 'about-wise',] }
                                

    wise.manage_addProperty('navigation_sections_left',
                            ['topics,Topics', 'quicklinks,Quick links'],
                            'lines')
    wise.manage_addProperty('navigation_sections_right',
                            ['data-center-services,Data centre services', 'featured,Featured articles','about,About wise'],
                            'lines')
                 
    for section, ids in wiseNave.items():
        folder = wise
        if section == 'data':
            folder = getattr(folder, 'data-center-services', folder)
            
        for objId in ids:
            obj = getattr(folder, objId, None)
            if obj is None:
                logger.info("themecentre (Wise migration): WARNING did not found %s in %s " % (objId, folder.getId()))
                continue
            obj.setExcludeFromNav(False)
            navContext = INavigationSectionPosition(obj)
            navContext.section = section
            info = Attributes(INavigationSectionPosition, 'section')            
            notify(ObjectModifiedEvent(obj, info))            

    wise.manage_changeProperties(left_slots=['here/portlet_themes/macros/portlet', 'here/portlet_logo/macros/portlet','here/@@leftNavigationSections', 'here/portlet_guestbook/macros/portlet'],
                                 right_slots=['here/portlet_themes_related/macros/portlet', 'here/@@rightNavigationSections',  'here/portlet_themes_rdf/macros/portlet'] )
    logger.info("themecentre (Wise migration): Wise navigation setup")
    
    # remove portlets from default page
    defaultPage = wise['welcome-to-water-information-system-for-europe-wise']
    defaultPage.manage_delProperties(ids=['left_slots', 'right_slots'])
    defaultPage.setLayout('themecentre_view')


    # rename links-to-mapviewer-2 due a 'bug' in theme centre navigation manager
    # if the url contains the word 'links' it is threated as the folder links
    # and only shown in default section
    # TODO fix the problem and remove this
    # TODO add rewrite rule for links-to-mapviewer-2
    wise.manage_renameObjects(ids=('links-to-mapviewer-2',), new_ids=('mapviewers',))
    logger.info("themecentre (Wise migration): Renamed links-to-mapviewer-2 to mapviewers, don't forget the rewrite rule")    

    # add subsite logo
    wise.invokeFactory('Image', id='subsite-logo', title='WISE logo')
    logo = wise['subsite-logo']
    path = os.path.join(package_home(GLOBALS),'..','WISETheme', 'skins', 'wisetheme_images','theme_logo.gif')
    imgData = open(path, 'rb')
    logo.setImage(imgData)
    logger.info("themecentre (Wise migration): Uploaded subsite logo")

    # publish objects so they appear in navigation
    wf = getToolByName(site, 'portal_workflow')

    # set navigation on central promotions
    catalog = getToolByName(site, 'portal_catalog')
    for promo in catalog.searchResults( portal_type='Promotion',
                                        getThemes='water' ):
        logger.info("themecentre (Wise migration): updating navigation section on %s" % promo.getURL)
        obj = promo.getObject()
        navContext = INavigationSectionPosition(obj)
        navContext.section = 'quicklinks'
        info = Attributes(INavigationSectionPosition, 'section')            
        notify(ObjectModifiedEvent(obj, info))                    
        

    # add local promotions
    promotions = [ {'id' : 'promo-guided-tours',
                    'title' : 'Guided tours to the map viewer',
                    'url' : '/themes/water/wise-help-centre/guided-tours/',
                    'section' : 'quicklinks',
                    'img' : 'boxmap_a.gif',
                    'imgCaption' : 'Click here to learn more about the map viewer' },
                   {'id' : 'promo-introduction-terms',
                    'title' : 'Introduction to general terms',
                    'url' : '/themes/water/wise-help-centre/guided-tours/introduction-to-general-terms',
                    'section' : 'quicklinks',
                    'img' : 'boxmap_b.gif',
                    'imgCaption' : 'Read an introduction to general hydrological terms.' },
                   {'id' : 'promo-expert-map',
                    'title' : 'Expert map and data access',
                    'url' : '/themes/water/wise-viewer',
                    'section' : 'quicklinks',
                    'img' : 'boxmap_c.gif',
                    'imgCaption' : 'Go to the expert WISE map viewer.' }]
    wise.setConstrainTypesMode(0)
    for promo in promotions:
        wise.invokeFactory('Promotion', id=promo['id'], title=promo['title'])
        obj = wise[promo['id']]
        obj.setUrl(promo['url'])
        navContext = INavigationSectionPosition(obj)
        navContext.section = promo['section']
        tagPromo = IThemeTagging(obj)
        tagPromo.tags = ['water']
        path = os.path.join(package_home(GLOBALS),'..','WISETheme', 'skins', 'wisetheme_images',promo['img'])
        imgData = open(path, 'rb')
        obj.setImage(imgData)
        obj.setImageCaption(promo['imgCaption'])
        info = Attributes(INavigationSectionPosition, 'section')            
        notify(ObjectModifiedEvent(obj, info))                    
        wf.doActionFor(obj, 'publish')
    wise.setConstrainTypesMode(1)    

    logger.info("themecentre (Wise migration): Wise Migrated")    


def setupVarious(context):
    # only run this step if we are in ThemeCentre profile
    # learned from Aspelis book, Professional Plone Development
    if context.readDataFile('themecentre_various.txt') is None:
        return

    site = context.getSite()
    logger = context.getLogger('themecentre')

    setupMultimediaVocabulary(context)
    setupMergedThemes(context)
    migrateListFeeds2pageWithRelatedFeed(context)

    setupThemesIndex(context)
    logger.info("themecentre_various: getThemes index is a method")

    return

def setupThemesIndex(context):
    site = context.getSite()
    catalog = getToolByName(site, 'portal_catalog')
    catalog.refreshCatalog()

def setupMultimediaVocabulary(context):
    site = context.getSite()
    vocab = getToolByName(site, 'portal_vocabularies')

    if not getattr(vocab, 'multimedia', None):
        vocab.invokeFactory('SimpleVocabulary', id='multimedia')

    media = [ ['video', 'Video'],
              ['interview', 'Interview'],
              ['interactivemap', 'Interactive Map'],
              ['mindstretcher', 'Mind Stretcher'],
              ['animation', 'Animation'],
              ['other', 'Other'],
            ]
    for id, title in media:
        if not getattr(vocab.multimedia, id, None):
            vocab.multimedia.invokeFactory('SimpleVocabularyTerm',
                                           id=id, title=title)

def setupMergedThemes(context):
    site = context.getSite()
    vocab = getToolByName(site, 'portal_vocabularies')

    if not getattr(vocab, 'themesmerged', None):
        vocab.invokeFactory('TreeVocabulary', id='themesmerged')
    mergedthemes = vocab.getVocabularyByName('themesmerged')
    
    themes = {'air_quality': 'air',
              'acidification': 'air'}

    for theme,mergedwith in themes.items():
        if not hasattr(mergedthemes, theme):
            tId = theme + "id"
            tId = mergedthemes.invokeFactory('TreeVocabularyTerm',
                                           id=tId)
            t = mergedthemes[tId]
            t.setTitle(theme)
            mId = mergedwith + "id"
            mId = mergedthemes[tId].invokeFactory('TreeVocabularyTerm',
                                           id=mId)
            t[mId].setTitle(mergedwith)

==> Products.ThemeCentre-1.4.zip: Products.ThemeCentre-1.4/Products/ThemeCentre/setuphandlers.py <==
from zope.interface import directlyProvides, directlyProvidedBy
from zope.app.event.objectevent import ObjectModifiedEvent, Attributes
from zope.event import notify

from Products.CMFCore.utils import getToolByName
from eea.themecentre.interfaces import IThemeCentreSchema, IThemeCentre, IThemeRelation, IThemeTagging
from eea.themecentre.browser.themecentre import PromoteThemeCentre
from Products.CMFPlone.browser.interfaces import INavigationRoot
from Products.NavigationManager.sections import INavigationSectionPosition

import os
from Globals import package_home
from Products.ThemeCentre import GLOBALS
from Acquisition import aq_inner


def migrateListFeeds2pageWithRelatedFeed(context):
    site = context.getSite()
    logger = context.getLogger('themecentre')
    catalog = getToolByName(site, 'portal_catalog')
    results = catalog.searchResults(object_provides='eea.themecentre.interfaces.IThemeCentre')
    wf = getToolByName(site, 'portal_workflow')
    for tBrain in results:
        theme = tBrain.getObject()

        if not hasattr(aq_inner(theme), 'reports'):
            feed_title = 'reports_%s' % theme.getId()
            feed = []

            if feed:
                theme.invokeFactory('Document', id='reports')
                reportPage = theme['reports']
                reportPage.setTitle('Reports')
                reportPage.setRelatedItems(feed[0].getObject().UID())
                wf.doActionFor(reportPage, 'publish')
            else:
                logger.info("themecentre (Wise migration): No feed %s " % feed_title)

        docId = 'maps-and-graphs'
        if not hasattr(aq_inner(theme), docId):
            feed = theme['rdf-repository'].Atlas
            theme.invokeFactory('Document', id=docId)
            doc = theme[docId]
            doc.setTitle('Maps and graphs')
            doc.setRelatedItems(feed.UID())
            wf.doActionFor(doc, 'publish')

        docId = 'datasets'
        if not hasattr(aq_inner(theme), docId):
            feed = theme['rdf-repository'].datasets
            theme.invokeFactory('Document', id=docId)
            doc = theme[docId]
            doc.setTitle('Datasets')
            doc.setRelatedItems(feed.UID())
            wf.doActionFor(doc, 'publish')



def migrateWise2ThemeCentre(context):
    # only run this step if we are in ThemeCentre profile
    if context.readDataFile('themecentre_migrate_wise.txt') is None:
        return

    site = context.getSite()
    logger = context.getLogger('themecentre')

    siteFolder = getattr(site, 'SITE', None)
    if siteFolder is None:
        return

    themes = getattr(site, 'themes', None)
    if themes is None:
        return

    water = getattr(themes, 'old-water', None)
    if water is None:
        logger.info("themecentre (Wise migration): No old water, migration skipped")
        return

    wise = themes.water

    # reload WISE profile
    setup_tool = getToolByName(site, 'portal_setup')
    setup_tool.setImportContext('profile-WISETheme:wisetheme')
    setup_tool.runImportStep('cssregistry')
    setup_tool.runImportStep('skins')
    setup_tool.setImportContext('profile-ThemeCentre:themecentre')

    # move stuff from water ThemeCentre
    objToMove = water.manage_cutObjects(ids=('indicators',))
    wise.manage_pasteObjects(objToMove)
    logger.info("themecentre (Wise migration): Moved indicators to wise folder")

    # enable Theme Centre on wise folder
    ptc = PromoteThemeCentre(wise, site.REQUEST)
    ptc()
    tc = IThemeCentreSchema(wise)
    tc.tags = 'water'
    logger.info("themecentre (Wise migration): Enabled theme centre on wise folder")

    # migrate related themes
    old = IThemeRelation(water)
    wiserelation = IThemeRelation(wise)
    wiserelation.related = old.related

    # disable old water as a theme centre
    tc = IThemeCentreSchema(water)
    tc.tags = None
    directlyProvides(water, directlyProvidedBy(wise) - IThemeCentre)
    logger.info("themecentre (Wise migration): Disabled theme centre on old water folder")
    # rename old-water to old-water-migrated, remove it manually when done
    themes.manage_renameObjects(ids=('old-water',), new_ids=('old-water-migrated',))
    logger.info("themecentre (Wise migration): Renamed old-water to old-water-migrated")



    # rermove navigation root on wise
    directlyProvides(wise, directlyProvidedBy(wise) - INavigationRoot)
    logger.info("themecentre (Wise migration): Removed INavigationRoot on wise folder")

    # setup wise navigation
    wiseNave = { 'topics' : [ 'european-waters', 'water-pollution',
                                'status-and-monitoring', 'water-resources',
                                'water-management', 'links-to-mapviewer-2',
                                'wise-help-centre', 'wise-evaluation-survey'],
                 'data-center-services' : [ 'data-center-services'],
                 'featured' : [ 'featured-articles', 'map-of-the-week'],
                 'about' : [ 'about-wise', ] }


    wise.manage_addProperty('navigation_sections_left',
                            ['topics,Topics', 'quicklinks,Quick links'],
                            'lines')
    wise.manage_addProperty('navigation_sections_right',
                            ['data-center-services,Data centre services', 'featured,Featured articles', 'about,About wise'],
                            'lines')

    for section, ids in wiseNave.items():
        folder = wise
        if section == 'data':
            folder = getattr(folder, 'data-center-services', folder)

        for objId in ids:
            obj = getattr(folder, objId, None)
            if obj is None:
                logger.info("themecentre (Wise migration): WARNING did not found %s in %s " % (objId, folder.getId()))
                continue
            obj.setExcludeFromNav(False)
            navContext = INavigationSectionPosition(obj)
            navContext.section = section
            info = Attributes(INavigationSectionPosition, 'section')
            notify(ObjectModifiedEvent(obj, info))

    wise.manage_changeProperties(left_slots=['here/portlet_themes/macros/portlet', 'here/portlet_logo/macros/portlet', 'here/@@leftNavigationSections', 'here/portlet_guestbook/macros/portlet'],
                                 right_slots=['here/portlet_themes_related/macros/portlet', 'here/@@rightNavigationSections', 'here/portlet_themes_rdf/macros/portlet'])
    logger.info("themecentre (Wise migration): Wise navigation setup")

    # remove portlets from default page
    defaultPage = wise['welcome-to-water-information-system-for-europe-wise']
    defaultPage.manage_delProperties(ids=['left_slots', 'right_slots'])
    defaultPage.setLayout('themecentre_view')


    # rename links-to-mapviewer-2 due a 'bug' in theme centre navigation manager
    # if the url contains the word 'links' it is threated as the folder links
    # and only shown in default section
    # TODO fix the problem and remove this
    # TODO add rewrite rule for links-to-mapviewer-2
    wise.manage_renameObjects(ids=('links-to-mapviewer-2',), new_ids=('mapviewers',))
    logger.info("themecentre (Wise migration): Renamed links-to-mapviewer-2 to mapviewers, don't forget the rewrite rule")

    # add subsite logo
    wise.invokeFactory('Image', id='subsite-logo', title='WISE logo')
    logo = wise['subsite-logo']
    path = os.path.join(package_home(GLOBALS), '..', 'WISETheme', 'skins', 'wisetheme_images', 'theme_logo.gif')
    imgData = open(path, 'rb')
    logo.setImage(imgData)
    logger.info("themecentre (Wise migration): Uploaded subsite logo")

    # publish objects so they appear in navigation
    wf = getToolByName(site, 'portal_workflow')

    # set navigation on central promotions
    catalog = getToolByName(site, 'portal_catalog')
    for promo in catalog.searchResults(portal_type='Promotion',
                                        getThemes='water'):
        logger.info("themecentre (Wise migration): updating navigation section on %s" % promo.getURL)
        obj = promo.getObject()
        navContext = INavigationSectionPosition(obj)
        navContext.section = 'quicklinks'
        info = Attributes(INavigationSectionPosition, 'section')
        notify(ObjectModifiedEvent(obj, info))


    # add local promotions
    promotions = [ {'id' : 'promo-guided-tours',
                    'title' : 'Guided tours to the map viewer',
                    'url' : '/themes/water/wise-help-centre/guided-tours/',
                    'section' : 'quicklinks',
                    'img' : 'boxmap_a.gif',
                    'imgCaption' : 'Click here to learn more about the map viewer' },
                   {'id' : 'promo-introduction-terms',
                    'title' : 'Introduction to general terms',
                    'url' : '/themes/water/wise-help-centre/guided-tours/introduction-to-general-terms',
                    'section' : 'quicklinks',
                    'img' : 'boxmap_b.gif',
                    'imgCaption' : 'Read an introduction to general hydrological terms.' },
                   {'id' : 'promo-expert-map',
                    'title' : 'Expert map and data access',
                    'url' : '/themes/water/wise-viewer',
                    'section' : 'quicklinks',
                    'img' : 'boxmap_c.gif',
                    'imgCaption' : 'Go to the expert WISE map viewer.' }]
    wise.setConstrainTypesMode(0)
    for promo in promotions:
        wise.invokeFactory('Promotion', id=promo['id'], title=promo['title'])
        obj = wise[promo['id']]
        obj.setUrl(promo['url'])
        navContext = INavigationSectionPosition(obj)
        navContext.section = promo['section']
        tagPromo = IThemeTagging(obj)
        tagPromo.tags = ['water']
        path = os.path.join(package_home(GLOBALS), '..', 'WISETheme', 'skins', 'wisetheme_images', promo['img'])
        imgData = open(path, 'rb')
        obj.setImage(imgData)
        obj.setImageCaption(promo['imgCaption'])
        info = Attributes(INavigationSectionPosition, 'section')
        notify(ObjectModifiedEvent(obj, info))
        wf.doActionFor(obj, 'publish')
    wise.setConstrainTypesMode(1)

    logger.info("themecentre (Wise migration): Wise Migrated")


def setupVarious(context):
    # only run this step if we are in ThemeCentre profile
    # learned from Aspelis book, Professional Plone Development
    if context.readDataFile('themecentre_various.txt') is None:
        return

    #site = context.getSite()
    logger = context.getLogger('themecentre')

    setupMultimediaVocabulary(context)
    setupMergedThemes(context)
    migrateListFeeds2pageWithRelatedFeed(context)

    setupThemesIndex(context)
    logger.info("themecentre_various: getThemes index is a method")

    return

def setupThemesIndex(context):
    site = context.getSite()
    catalog = getToolByName(site, 'portal_catalog')
    catalog.refreshCatalog()

def setupMultimediaVocabulary(context):
    site = context.getSite()
    vocab = getToolByName(site, 'portal_vocabularies')

    if not getattr(vocab, 'multimedia', None):
        vocab.invokeFactory('SimpleVocabulary', id='multimedia')

    media = [ ['video', 'Video'],
              ['interview', 'Interview'],
              ['interactivemap', 'Interactive Map'],
              ['mindstretcher', 'Mind Stretcher'],
              ['animation', 'Animation'],
              ['other', 'Other'],
            ]
    for mid, title in media:
        if not getattr(vocab.multimedia, mid, None):
            vocab.multimedia.invokeFactory('SimpleVocabularyTerm',
                                           id=mid, title=title)

def setupMergedThemes(context):
    site = context.getSite()
    vocab = getToolByName(site, 'portal_vocabularies')

    if not getattr(vocab, 'themesmerged', None):
        vocab.invokeFactory('TreeVocabulary', id='themesmerged')
    mergedthemes = vocab.getVocabularyByName('themesmerged')

    themes = {'air_quality': 'air',
              'acidification': 'air'}

    for theme, mergedwith in themes.items():
        if not hasattr(mergedthemes, theme):
            tId = theme + "id"
            tId = mergedthemes.invokeFactory('TreeVocabularyTerm',
                                           id=tId)
            t = mergedthemes[tId]
            t.setTitle(theme)
            mId = mergedwith + "id"
            mId = mergedthemes[tId].invokeFactory('TreeVocabularyTerm',
                                           id=mId)
            t[mId].setTitle(mergedwith)
